var hierarchy =
[
    [ "AEffEditor", null, [
      [ "AEffGUIEditor", "class_v_s_t_g_u_i_1_1_a_eff_g_u_i_editor.html", null ]
    ] ],
    [ "AlertBoxConfig", "struct_v_s_t_g_u_i_1_1_standalone_1_1_alert_box_config.html", [
      [ "AlertBoxForWindowConfig", "struct_v_s_t_g_u_i_1_1_standalone_1_1_alert_box_for_window_config.html", null ]
    ] ],
    [ "Auto", "struct_v_s_t_g_u_i_1_1_grid_layout_properties_1_1_auto.html", null ],
    [ "AutoLayout", "class_v_s_t_g_u_i_1_1_layouting_1_1_auto_layout.html", null ],
    [ "Base64Codec", "class_v_s_t_g_u_i_1_1_base64_codec.html", null ],
    [ "BaseViewLayouterEntry", "struct_v_s_t_g_u_i_1_1_base_view_layouter_entry.html", null ],
    [ "BitScopeToggleT< T, B >", "struct_v_s_t_g_u_i_1_1_bit_scope_toggle_t.html", null ],
    [ "Buffer< T, Allocator >", "class_v_s_t_g_u_i_1_1_buffer.html", null ],
    [ "CBaseObjectGuard", "class_v_s_t_g_u_i_1_1_c_base_object_guard.html", null ],
    [ "CButtonState", "struct_v_s_t_g_u_i_1_1_c_button_state.html", null ],
    [ "CClipboard", "struct_v_s_t_g_u_i_1_1_c_clipboard.html", null ],
    [ "CColor", "struct_v_s_t_g_u_i_1_1_c_color.html", null ],
    [ "CColorChooserUISettings", "struct_v_s_t_g_u_i_1_1_c_color_chooser_u_i_settings.html", null ],
    [ "CDragContainerHelper", "class_v_s_t_g_u_i_1_1_c_drag_container_helper.html", null ],
    [ "CDrawMode", "struct_v_s_t_g_u_i_1_1_c_draw_mode.html", null ],
    [ "Cell", "struct_v_s_t_g_u_i_1_1_c_data_browser_1_1_cell.html", null ],
    [ "CExternalViewBaseImpl", "struct_v_s_t_g_u_i_1_1_c_external_view_base_impl.html", [
      [ "Impl", "struct_v_s_t_g_u_i_1_1_c_external_control_1_1_impl.html", null ],
      [ "Impl", "struct_v_s_t_g_u_i_1_1_c_external_view_1_1_impl.html", null ]
    ] ],
    [ "CFileExtension", "class_v_s_t_g_u_i_1_1_c_file_extension.html", null ],
    [ "CFontChooserUIDefinition", "struct_v_s_t_g_u_i_1_1_c_font_chooser_u_i_definition.html", null ],
    [ "CGraphicsTransform", "struct_v_s_t_g_u_i_1_1_c_graphics_transform.html", null ],
    [ "CInvalidRectList", "struct_v_s_t_g_u_i_1_1_c_invalid_rect_list.html", null ],
    [ "CLineStyle", "class_v_s_t_g_u_i_1_1_c_line_style.html", null ],
    [ "CListControlRowDesc", "struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html", null ],
    [ "CMouseWheelEditingSupport", "class_v_s_t_g_u_i_1_1_c_mouse_wheel_editing_support.html", [
      [ "CKnobBase", "class_v_s_t_g_u_i_1_1_c_knob_base.html", [
        [ "CAnimKnob", "class_v_s_t_g_u_i_1_1_c_anim_knob.html", null ],
        [ "CKnob", "class_v_s_t_g_u_i_1_1_c_knob.html", null ]
      ] ],
      [ "CSliderBase", "class_v_s_t_g_u_i_1_1_c_slider_base.html", [
        [ "CSlider", "class_v_s_t_g_u_i_1_1_c_slider.html", [
          [ "CHorizontalSlider", "class_v_s_t_g_u_i_1_1_c_horizontal_slider.html", null ],
          [ "CVerticalSlider", "class_v_s_t_g_u_i_1_1_c_vertical_slider.html", null ]
        ] ]
      ] ],
      [ "CXYPad", "class_v_s_t_g_u_i_1_1_c_x_y_pad.html", null ]
    ] ],
    [ "CMultiFrameBitmapDescription", "struct_v_s_t_g_u_i_1_1_c_multi_frame_bitmap_description.html", null ],
    [ "CNinePartTiledDescription", "struct_v_s_t_g_u_i_1_1_c_nine_part_tiled_description.html", null ],
    [ "CollectInvalidRects", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_collect_invalid_rects.html", null ],
    [ "Command", "struct_v_s_t_g_u_i_1_1_standalone_1_1_command.html", null ],
    [ "ConcatClip", "struct_v_s_t_g_u_i_1_1_concat_clip.html", null ],
    [ "Config", "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_config.html", null ],
    [ "ConfigValue", "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_config_value.html", null ],
    [ "CPoint", "struct_v_s_t_g_u_i_1_1_c_point.html", null ],
    [ "CRect", "struct_v_s_t_g_u_i_1_1_c_rect.html", null ],
    [ "CResourceDescription", "class_v_s_t_g_u_i_1_1_c_resource_description.html", null ],
    [ "CSSNamedColor", "struct_v_s_t_g_u_i_1_1_c_s_s_named_color.html", null ],
    [ "DataPackageIterator", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html", null ],
    [ "DeferChanges", "class_v_s_t_g_u_i_1_1_i_dependency_1_1_defer_changes.html", null ],
    [ "Desc", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html", null ],
    [ "DispatchList< T >", "class_v_s_t_g_u_i_1_1_dispatch_list.html", null ],
    [ "DragDescription", "struct_v_s_t_g_u_i_1_1_drag_description.html", null ],
    [ "DragEventData", "struct_v_s_t_g_u_i_1_1_drag_event_data.html", null ],
    [ "DragStartMouseObserver", "struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer.html", null ],
    [ "EditCallbacks", "struct_v_s_t_g_u_i_1_1_external_view_1_1_i_control_view_extension_1_1_edit_callbacks.html", null ],
    [ "enable_shared_from_this", null, [
      [ "Group", "struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html", null ]
    ] ],
    [ "EnumBitset< Enum, EnumIsBitMask >", "struct_v_s_t_g_u_i_1_1_enum_bitset.html", null ],
    [ "ERect", "struct_v_s_t_g_u_i_1_1_e_rect.html", null ],
    [ "Event", "struct_v_s_t_g_u_i_1_1_event.html", [
      [ "ModifierEvent", "struct_v_s_t_g_u_i_1_1_modifier_event.html", [
        [ "KeyboardEvent", "struct_v_s_t_g_u_i_1_1_keyboard_event.html", null ],
        [ "MousePositionEvent", "struct_v_s_t_g_u_i_1_1_mouse_position_event.html", [
          [ "GestureEvent", "struct_v_s_t_g_u_i_1_1_gesture_event.html", [
            [ "ZoomGestureEvent", "struct_v_s_t_g_u_i_1_1_zoom_gesture_event.html", null ]
          ] ],
          [ "MouseEvent", "struct_v_s_t_g_u_i_1_1_mouse_event.html", [
            [ "MouseDownUpMoveEvent", "struct_v_s_t_g_u_i_1_1_mouse_down_up_move_event.html", [
              [ "MouseDownEvent", "struct_v_s_t_g_u_i_1_1_mouse_down_event.html", null ],
              [ "MouseMoveEvent", "struct_v_s_t_g_u_i_1_1_mouse_move_event.html", null ],
              [ "MouseUpEvent", "struct_v_s_t_g_u_i_1_1_mouse_up_event.html", null ]
            ] ],
            [ "MouseEnterEvent", "struct_v_s_t_g_u_i_1_1_mouse_enter_event.html", null ],
            [ "MouseExitEvent", "struct_v_s_t_g_u_i_1_1_mouse_exit_event.html", null ]
          ] ],
          [ "MouseWheelEvent", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html", null ]
        ] ]
      ] ],
      [ "MouseCancelEvent", "struct_v_s_t_g_u_i_1_1_mouse_cancel_event.html", null ]
    ] ],
    [ "EventConsumeState", "struct_v_s_t_g_u_i_1_1_event_consume_state.html", null ],
    [ "Factory", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_factory.html", null ],
    [ "FinalAction< Proc >", "class_v_s_t_g_u_i_1_1_final_action.html", null ],
    [ "FObject", null, [
      [ "GroupController", "class_v_s_t_g_u_i_1_1_group_controller.html", null ],
      [ "PadController", "class_v_s_t_g_u_i_1_1_pad_controller.html", null ],
      [ "ParameterChangeListener", "class_v_s_t_g_u_i_1_1_parameter_change_listener.html", null ]
    ] ],
    [ "FocusDrawingSettings", "struct_v_s_t_g_u_i_1_1_focus_drawing_settings.html", null ],
    [ "GenericStringListDataBrowserSourceSelectionChanged", "class_v_s_t_g_u_i_1_1_generic_string_list_data_browser_source_selection_changed.html", [
      [ "CFontChooser", "class_v_s_t_g_u_i_1_1_c_font_chooser.html", null ]
    ] ],
    [ "GetViewOptions", "struct_v_s_t_g_u_i_1_1_get_view_options.html", null ],
    [ "GlobalFonts", "struct_v_s_t_g_u_i_1_1_global_fonts.html", null ],
    [ "GridArea", "struct_v_s_t_g_u_i_1_1_grid_layout_properties_1_1_grid_area.html", null ],
    [ "GridLayoutProperties", "struct_v_s_t_g_u_i_1_1_grid_layout_properties.html", null ],
    [ "IAnimationTarget", "class_v_s_t_g_u_i_1_1_animation_1_1_i_animation_target.html", [
      [ "AlphaValueAnimation", "class_v_s_t_g_u_i_1_1_animation_1_1_alpha_value_animation.html", null ],
      [ "ControlValueAnimation", "class_v_s_t_g_u_i_1_1_animation_1_1_control_value_animation.html", null ],
      [ "ExchangeViewAnimation", "class_v_s_t_g_u_i_1_1_animation_1_1_exchange_view_animation.html", null ],
      [ "FuncAnimation", "class_v_s_t_g_u_i_1_1_animation_1_1_func_animation.html", null ],
      [ "ViewSizeAnimation", "class_v_s_t_g_u_i_1_1_animation_1_1_view_size_animation.html", null ]
    ] ],
    [ "IBitmapCreator", "class_v_s_t_g_u_i_1_1_i_bitmap_creator.html", null ],
    [ "IBitmapCreator2", "class_v_s_t_g_u_i_1_1_i_bitmap_creator2.html", null ],
    [ "IColorChooserDelegate", "class_v_s_t_g_u_i_1_1_i_color_chooser_delegate.html", null ],
    [ "IContentProvider", "class_v_s_t_g_u_i_1_1_i_content_provider.html", [
      [ "InputStreamContentProvider", "class_v_s_t_g_u_i_1_1_input_stream_content_provider.html", null ],
      [ "MemoryContentProvider", "class_v_s_t_g_u_i_1_1_memory_content_provider.html", null ],
      [ "ZLibInputContentProvider", "class_v_s_t_g_u_i_1_1_z_lib_input_content_provider.html", null ]
    ] ],
    [ "IContextMenuController", "class_v_s_t_g_u_i_1_1_i_context_menu_controller.html", null ],
    [ "IContextMenuController2", "class_v_s_t_g_u_i_1_1_i_context_menu_controller2.html", null ],
    [ "IControlListener", "class_v_s_t_g_u_i_1_1_i_control_listener.html", [
      [ "CColorChooser", "class_v_s_t_g_u_i_1_1_c_color_chooser.html", null ],
      [ "CFontChooser", "class_v_s_t_g_u_i_1_1_c_font_chooser.html", null ],
      [ "CScrollView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html", [
        [ "CDataBrowser", "class_v_s_t_g_u_i_1_1_c_data_browser.html", null ]
      ] ],
      [ "CSplashScreen", "class_v_s_t_g_u_i_1_1_c_splash_screen.html", [
        [ "CAnimationSplashScreen", "class_v_s_t_g_u_i_1_1_c_animation_splash_screen.html", null ]
      ] ],
      [ "CTabView", "class_v_s_t_g_u_i_1_1_c_tab_view.html", null ],
      [ "IController", "class_v_s_t_g_u_i_1_1_i_controller.html", [
        [ "DelegationController", "class_v_s_t_g_u_i_1_1_delegation_controller.html", [
          [ "PadController", "class_v_s_t_g_u_i_1_1_pad_controller.html", null ]
        ] ],
        [ "GroupController", "class_v_s_t_g_u_i_1_1_group_controller.html", null ],
        [ "VST3Editor", "class_v_s_t_g_u_i_1_1_v_s_t3_editor.html", [
          [ "AspectRatioVST3Editor", "class_v_s_t_g_u_i_1_1_aspect_ratio_v_s_t3_editor.html", null ]
        ] ]
      ] ],
      [ "FindPanelController", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_find_panel_controller.html", null ],
      [ "UIDescriptionViewSwitchController", "class_v_s_t_g_u_i_1_1_u_i_description_view_switch_controller.html", null ]
    ] ],
    [ "IControlViewExtension", "struct_v_s_t_g_u_i_1_1_external_view_1_1_i_control_view_extension.html", [
      [ "ControlViewAdapter", "struct_v_s_t_g_u_i_1_1_external_view_1_1_control_view_adapter.html", null ]
    ] ],
    [ "IDataBrowserDelegate", "class_v_s_t_g_u_i_1_1_i_data_browser_delegate.html", [
      [ "DataBrowserDelegateAdapter", "class_v_s_t_g_u_i_1_1_data_browser_delegate_adapter.html", [
        [ "GenericStringListDataBrowserSource", "class_v_s_t_g_u_i_1_1_generic_string_list_data_browser_source.html", null ]
      ] ]
    ] ],
    [ "IDependency", "class_v_s_t_g_u_i_1_1_i_dependency.html", null ],
    [ "IDraggingSession", "class_v_s_t_g_u_i_1_1_i_dragging_session.html", null ],
    [ "IDrawLinearGradientLine", "struct_v_s_t_g_u_i_1_1_c_draw_context_1_1_i_draw_linear_gradient_line.html", null ],
    [ "IEditorExt", "struct_v_s_t_g_u_i_1_1_text_editor_colorization_1_1_i_editor_ext.html", [
      [ "TextEditorView", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_text_editor_view.html", null ]
    ] ],
    [ "IFocusDrawing", "class_v_s_t_g_u_i_1_1_i_focus_drawing.html", [
      [ "CControl", "class_v_s_t_g_u_i_1_1_c_control.html", [
        [ "CAutoAnimation", "class_v_s_t_g_u_i_1_1_c_auto_animation.html", null ],
        [ "CCheckBox", "class_v_s_t_g_u_i_1_1_c_check_box.html", null ],
        [ "CExternalControl", "class_v_s_t_g_u_i_1_1_c_external_control.html", null ],
        [ "CKickButton", "class_v_s_t_g_u_i_1_1_c_kick_button.html", null ],
        [ "CKnobBase", "class_v_s_t_g_u_i_1_1_c_knob_base.html", null ],
        [ "CListControl", "class_v_s_t_g_u_i_1_1_c_list_control.html", null ],
        [ "CMovieBitmap", "class_v_s_t_g_u_i_1_1_c_movie_bitmap.html", null ],
        [ "CMovieButton", "class_v_s_t_g_u_i_1_1_c_movie_button.html", null ],
        [ "COnOffButton", "class_v_s_t_g_u_i_1_1_c_on_off_button.html", null ],
        [ "CParamDisplay", "class_v_s_t_g_u_i_1_1_c_param_display.html", [
          [ "COptionMenu", "class_v_s_t_g_u_i_1_1_c_option_menu.html", null ],
          [ "CTextLabel", "class_v_s_t_g_u_i_1_1_c_text_label.html", [
            [ "CMultiLineTextLabel", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html", null ],
            [ "CTextEdit", "class_v_s_t_g_u_i_1_1_c_text_edit.html", [
              [ "CSearchTextEdit", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html", null ]
            ] ]
          ] ],
          [ "CXYPad", "class_v_s_t_g_u_i_1_1_c_x_y_pad.html", null ]
        ] ],
        [ "CRockerSwitch", "class_v_s_t_g_u_i_1_1_c_rocker_switch.html", null ],
        [ "CScrollbar", "class_v_s_t_g_u_i_1_1_c_scrollbar.html", null ],
        [ "CSegmentButton", "class_v_s_t_g_u_i_1_1_c_segment_button.html", null ],
        [ "CSliderBase", "class_v_s_t_g_u_i_1_1_c_slider_base.html", null ],
        [ "CSpecialDigit", "class_v_s_t_g_u_i_1_1_c_special_digit.html", null ],
        [ "CSplashScreen", "class_v_s_t_g_u_i_1_1_c_splash_screen.html", null ],
        [ "CSwitchBase", "class_v_s_t_g_u_i_1_1_c_switch_base.html", [
          [ "CHorizontalSwitch", "class_v_s_t_g_u_i_1_1_c_horizontal_switch.html", null ],
          [ "CVerticalSwitch", "class_v_s_t_g_u_i_1_1_c_vertical_switch.html", null ]
        ] ],
        [ "CTextButton", "class_v_s_t_g_u_i_1_1_c_text_button.html", null ],
        [ "CVuMeter", "class_v_s_t_g_u_i_1_1_c_vu_meter.html", null ],
        [ "CControlCreatorDummyControl", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_c_control_creator_dummy_control.html", null ]
      ] ],
      [ "TextEditorView", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_text_editor_view.html", null ]
    ] ],
    [ "IFocusViewObserver", "class_v_s_t_g_u_i_1_1_i_focus_view_observer.html", null ],
    [ "IFontChooserDelegate", "class_v_s_t_g_u_i_1_1_i_font_chooser_delegate.html", null ],
    [ "IHandler", "class_v_s_t_g_u_i_1_1_xml_1_1_i_handler.html", null ],
    [ "IKeyboardHook", "class_v_s_t_g_u_i_1_1_i_keyboard_hook.html", [
      [ "OldKeyboardHookAdapter", "class_v_s_t_g_u_i_1_1_old_keyboard_hook_adapter.html", null ]
    ] ],
    [ "IMouseObserver", "class_v_s_t_g_u_i_1_1_i_mouse_observer.html", [
      [ "OldMouseObserverAdapter", "class_v_s_t_g_u_i_1_1_old_mouse_observer_adapter.html", null ],
      [ "VST3Editor", "class_v_s_t_g_u_i_1_1_v_s_t3_editor.html", null ]
    ] ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_c_draw_context_1_1_impl.html", null ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html", null ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html", null ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_c_menu_item_1_1_impl.html", null ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_c_slider_1_1_impl.html", null ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_c_slider_base_1_1_impl.html", null ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html", null ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html", null ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_string_list_control_drawer_1_1_impl.html", null ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_u_i_description_add_on_registry_1_1_impl.html", null ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_z_lib_input_stream_1_1_impl.html", null ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_z_lib_output_stream_1_1_impl.html", null ],
    [ "IMultiBitmapControl", "class_v_s_t_g_u_i_1_1_i_multi_bitmap_control.html", [
      [ "CAnimKnob", "class_v_s_t_g_u_i_1_1_c_anim_knob.html", null ],
      [ "CAutoAnimation", "class_v_s_t_g_u_i_1_1_c_auto_animation.html", null ],
      [ "CKickButton", "class_v_s_t_g_u_i_1_1_c_kick_button.html", null ],
      [ "CMovieBitmap", "class_v_s_t_g_u_i_1_1_c_movie_bitmap.html", null ],
      [ "CMovieButton", "class_v_s_t_g_u_i_1_1_c_movie_button.html", null ],
      [ "CRockerSwitch", "class_v_s_t_g_u_i_1_1_c_rocker_switch.html", null ],
      [ "CSwitchBase", "class_v_s_t_g_u_i_1_1_c_switch_base.html", null ]
    ] ],
    [ "IMultiBitmapControlCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_i_multi_bitmap_control_creator.html", null ],
    [ "Info", "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_info.html", null ],
    [ "Init", "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_init.html", null ],
    [ "InputStream", "class_v_s_t_g_u_i_1_1_input_stream.html", [
      [ "CFileStream", "class_v_s_t_g_u_i_1_1_c_file_stream.html", null ],
      [ "CMemoryStream", "class_v_s_t_g_u_i_1_1_c_memory_stream.html", [
        [ "MemoryContentProvider", "class_v_s_t_g_u_i_1_1_memory_content_provider.html", null ]
      ] ],
      [ "CResourceInputStream", "class_v_s_t_g_u_i_1_1_c_resource_input_stream.html", null ],
      [ "ZLibInputStream", "class_v_s_t_g_u_i_1_1_z_lib_input_stream.html", null ]
    ] ],
    [ "Interface", "class_v_s_t_g_u_i_1_1_interface.html", [
      [ "IDelegate", "class_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_i_delegate.html", [
        [ "DelegateAdapter", "class_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_delegate_adapter.html", null ]
      ] ],
      [ "IApplication", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_application.html", null ],
      [ "ICommandHandler", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_command_handler.html", null ],
      [ "ICommonDirectories", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_common_directories.html", null ],
      [ "IMenuBuilder", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_menu_builder.html", [
        [ "MenuBuilderAdapter", "class_v_s_t_g_u_i_1_1_standalone_1_1_menu_builder_adapter.html", [
          [ "NoMenuBuilder", "class_v_s_t_g_u_i_1_1_standalone_1_1_no_menu_builder.html", null ]
        ] ]
      ] ],
      [ "IMutableStepValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_mutable_step_value.html", null ],
      [ "IPreference", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_preference.html", null ],
      [ "IRangeValueConverter", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_range_value_converter.html", null ],
      [ "ISharedUIResources", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_shared_u_i_resources.html", null ],
      [ "IStepValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_step_value.html", null ],
      [ "IStringListValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_list_value.html", null ],
      [ "IStringValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_value.html", null ],
      [ "IUIDescWindowController", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_u_i_desc_window_controller.html", null ],
      [ "IValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value.html", null ],
      [ "IValueConverter", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_converter.html", null ],
      [ "IValueListener", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_listener.html", [
        [ "ListenerBase", "class_v_s_t_g_u_i_1_1_standalone_1_1_value_1_1_detail_1_1_listener_base.html", [
          [ "Listener", "class_v_s_t_g_u_i_1_1_standalone_1_1_value_1_1_listener.html", null ],
          [ "ListenerT< Context >", "class_v_s_t_g_u_i_1_1_standalone_1_1_value_1_1_listener_t.html", null ]
        ] ],
        [ "ValueListenerAdapter", "class_v_s_t_g_u_i_1_1_standalone_1_1_value_listener_adapter.html", [
          [ "ModelBindingCallbacks", "class_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_model_binding_callbacks.html", null ]
        ] ]
      ] ],
      [ "IWindow", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_window.html", null ],
      [ "IWindowListener", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_window_listener.html", [
        [ "IWindowController", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_window_controller.html", [
          [ "WindowControllerAdapter", "class_v_s_t_g_u_i_1_1_standalone_1_1_window_controller_adapter.html", null ]
        ] ],
        [ "WindowListenerAdapter", "class_v_s_t_g_u_i_1_1_standalone_1_1_window_listener_adapter.html", [
          [ "WindowClosedListener", "class_v_s_t_g_u_i_1_1_standalone_1_1_window_closed_listener.html", null ]
        ] ]
      ] ],
      [ "ICustomization", "class_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_i_customization.html", [
        [ "CustomizationAdapter", "class_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_customization_adapter.html", [
          [ "Customization", "class_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_customization.html", null ]
        ] ]
      ] ],
      [ "IModelBinding", "class_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_i_model_binding.html", [
        [ "ModelBindingCallbacks", "class_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_model_binding_callbacks.html", null ]
      ] ]
    ] ],
    [ "IntPoint", "struct_v_s_t_g_u_i_1_1_external_view_1_1_int_point.html", null ],
    [ "IntRect", "struct_v_s_t_g_u_i_1_1_external_view_1_1_int_rect.html", null ],
    [ "IntSize", "struct_v_s_t_g_u_i_1_1_external_view_1_1_int_size.html", null ],
    [ "IOpenGLView", null, [
      [ "COpenGLView", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html", null ]
    ] ],
    [ "IOptionMenuListener", "class_v_s_t_g_u_i_1_1_i_option_menu_listener.html", [
      [ "OptionMenuListenerAdapter", "class_v_s_t_g_u_i_1_1_option_menu_listener_adapter.html", null ]
    ] ],
    [ "IParameterFinder", null, [
      [ "VST3Editor", "class_v_s_t_g_u_i_1_1_v_s_t3_editor.html", null ]
    ] ],
    [ "IPlatformFrameCallback", null, [
      [ "CFrame", "class_v_s_t_g_u_i_1_1_c_frame.html", null ]
    ] ],
    [ "IPlatformTextEditCallback", null, [
      [ "CTextEdit", "class_v_s_t_g_u_i_1_1_c_text_edit.html", null ]
    ] ],
    [ "IPlatformTimerCallback", null, [
      [ "CVSTGUITimer", "class_v_s_t_g_u_i_1_1_c_v_s_t_g_u_i_timer.html", null ]
    ] ],
    [ "IPlatformViewLayerDelegate", null, [
      [ "CLayeredViewContainer", "class_v_s_t_g_u_i_1_1_c_layered_view_container.html", null ]
    ] ],
    [ "IReference", "class_v_s_t_g_u_i_1_1_i_reference.html", [
      [ "ReferenceCounted< std::atomic< int32_t > >", "class_v_s_t_g_u_i_1_1_reference_counted.html", [
        [ "CBitmap", "class_v_s_t_g_u_i_1_1_c_bitmap.html", [
          [ "CMultiFrameBitmap", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html", null ],
          [ "CNinePartTiledBitmap", "class_v_s_t_g_u_i_1_1_c_nine_part_tiled_bitmap.html", null ]
        ] ],
        [ "CBitmapPixelAccess", "class_v_s_t_g_u_i_1_1_c_bitmap_pixel_access.html", null ],
        [ "CDrawContext", "class_v_s_t_g_u_i_1_1_c_draw_context.html", [
          [ "COffscreenContext", "class_v_s_t_g_u_i_1_1_c_offscreen_context.html", null ]
        ] ],
        [ "CFileStream", "class_v_s_t_g_u_i_1_1_c_file_stream.html", null ],
        [ "CFontDesc", "class_v_s_t_g_u_i_1_1_c_font_desc.html", null ],
        [ "CGradient", "class_v_s_t_g_u_i_1_1_c_gradient.html", null ],
        [ "CGraphicsPath", "class_v_s_t_g_u_i_1_1_c_graphics_path.html", null ],
        [ "CMemoryStream", "class_v_s_t_g_u_i_1_1_c_memory_stream.html", null ],
        [ "IDataPackage", "class_v_s_t_g_u_i_1_1_i_data_package.html", [
          [ "StringDataPackage< AsFile >", "struct_v_s_t_g_u_i_1_1_c_clipboard_detail_1_1_string_data_package.html", null ],
          [ "CDropSource", "class_v_s_t_g_u_i_1_1_c_drop_source.html", null ]
        ] ]
      ] ],
      [ "ReferenceCounted< int32_t >", "class_v_s_t_g_u_i_1_1_reference_counted.html", [
        [ "AlphaValueAnimation", "class_v_s_t_g_u_i_1_1_animation_1_1_alpha_value_animation.html", null ],
        [ "Animator", "class_v_s_t_g_u_i_1_1_animation_1_1_animator.html", null ],
        [ "ControlValueAnimation", "class_v_s_t_g_u_i_1_1_animation_1_1_control_value_animation.html", null ],
        [ "ExchangeViewAnimation", "class_v_s_t_g_u_i_1_1_animation_1_1_exchange_view_animation.html", null ],
        [ "FuncAnimation", "class_v_s_t_g_u_i_1_1_animation_1_1_func_animation.html", null ],
        [ "ViewSizeAnimation", "class_v_s_t_g_u_i_1_1_animation_1_1_view_size_animation.html", null ],
        [ "IFilter", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_i_filter.html", [
          [ "FilterBase", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html", null ]
        ] ],
        [ "CBaseObject", "class_v_s_t_g_u_i_1_1_c_base_object.html", [
          [ "FinishedMessage", "class_v_s_t_g_u_i_1_1_animation_1_1_finished_message.html", null ],
          [ "CMenuItem", "class_v_s_t_g_u_i_1_1_c_menu_item.html", [
            [ "CCommandMenuItem", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html", null ]
          ] ],
          [ "CNewFileSelector", "class_v_s_t_g_u_i_1_1_c_new_file_selector.html", null ],
          [ "CTooltipSupport", "class_v_s_t_g_u_i_1_1_c_tooltip_support.html", null ],
          [ "CVSTGUITimer", "class_v_s_t_g_u_i_1_1_c_v_s_t_g_u_i_timer.html", null ],
          [ "CView", "class_v_s_t_g_u_i_1_1_c_view.html", [
            [ "CControl", "class_v_s_t_g_u_i_1_1_c_control.html", null ],
            [ "CExternalView", "class_v_s_t_g_u_i_1_1_c_external_view.html", null ],
            [ "CGradientView", "class_v_s_t_g_u_i_1_1_c_gradient_view.html", null ],
            [ "COpenGLView", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html", null ],
            [ "CViewContainer", "class_v_s_t_g_u_i_1_1_c_view_container.html", [
              [ "CAutoLayoutContainerView", "class_v_s_t_g_u_i_1_1_c_auto_layout_container_view.html", [
                [ "CRowColumnView", "class_v_s_t_g_u_i_1_1_c_row_column_view.html", null ]
              ] ],
              [ "CColorChooser", "class_v_s_t_g_u_i_1_1_c_color_chooser.html", null ],
              [ "CFontChooser", "class_v_s_t_g_u_i_1_1_c_font_chooser.html", null ],
              [ "CFrame", "class_v_s_t_g_u_i_1_1_c_frame.html", null ],
              [ "CLayeredViewContainer", "class_v_s_t_g_u_i_1_1_c_layered_view_container.html", null ],
              [ "CScrollView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html", null ],
              [ "CShadowViewContainer", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html", null ],
              [ "CSplitView", "class_v_s_t_g_u_i_1_1_c_split_view.html", null ],
              [ "CTabView", "class_v_s_t_g_u_i_1_1_c_tab_view.html", null ],
              [ "UIViewSwitchContainer", "class_v_s_t_g_u_i_1_1_u_i_view_switch_container.html", null ]
            ] ],
            [ "LineNumberView", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_line_number_view.html", null ],
            [ "TextEditorView", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_text_editor_view.html", null ]
          ] ],
          [ "GenericStringListDataBrowserSource", "class_v_s_t_g_u_i_1_1_generic_string_list_data_browser_source.html", null ],
          [ "UIDescriptionViewSwitchController", "class_v_s_t_g_u_i_1_1_u_i_description_view_switch_controller.html", null ]
        ] ],
        [ "CViewContainerDropTarget", "struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html", null ],
        [ "DragCallbackFunctions", "class_v_s_t_g_u_i_1_1_drag_callback_functions.html", null ],
        [ "GridLayouter", "class_v_s_t_g_u_i_1_1_grid_layouter.html", null ],
        [ "NoViewLayouter", "struct_v_s_t_g_u_i_1_1_no_view_layouter.html", null ],
        [ "StaticListControlConfigurator", "class_v_s_t_g_u_i_1_1_static_list_control_configurator.html", null ],
        [ "StringListControlDrawer", "class_v_s_t_g_u_i_1_1_string_list_control_drawer.html", null ],
        [ "UIAttributes", "class_v_s_t_g_u_i_1_1_u_i_attributes.html", null ],
        [ "UIDescription", "class_v_s_t_g_u_i_1_1_u_i_description.html", [
          [ "CompressedUIDescription", "class_v_s_t_g_u_i_1_1_compressed_u_i_description.html", null ]
        ] ],
        [ "UIViewFactory", "class_v_s_t_g_u_i_1_1_u_i_view_factory.html", null ]
      ] ],
      [ "ICommandMenuItemTarget", "class_v_s_t_g_u_i_1_1_i_command_menu_item_target.html", [
        [ "CommandMenuItemTargetAdapter", "class_v_s_t_g_u_i_1_1_command_menu_item_target_adapter.html", [
          [ "VST3Editor", "class_v_s_t_g_u_i_1_1_v_s_t3_editor.html", null ]
        ] ]
      ] ],
      [ "IDragCallback", "class_v_s_t_g_u_i_1_1_i_drag_callback.html", [
        [ "DragCallbackAdapter", "class_v_s_t_g_u_i_1_1_drag_callback_adapter.html", null ],
        [ "DragCallbackFunctions", "class_v_s_t_g_u_i_1_1_drag_callback_functions.html", null ]
      ] ],
      [ "IDropTarget", "class_v_s_t_g_u_i_1_1_i_drop_target.html", [
        [ "CViewContainerDropTarget", "struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html", null ],
        [ "DropTargetAdapter", "class_v_s_t_g_u_i_1_1_drop_target_adapter.html", null ]
      ] ],
      [ "IListControlConfigurator", "class_v_s_t_g_u_i_1_1_i_list_control_configurator.html", [
        [ "StaticListControlConfigurator", "class_v_s_t_g_u_i_1_1_static_list_control_configurator.html", null ]
      ] ],
      [ "IListControlDrawer", "class_v_s_t_g_u_i_1_1_i_list_control_drawer.html", [
        [ "StringListControlDrawer", "class_v_s_t_g_u_i_1_1_string_list_control_drawer.html", null ]
      ] ],
      [ "IViewLayouter", "class_v_s_t_g_u_i_1_1_i_view_layouter.html", [
        [ "BaseViewLayouter", "class_v_s_t_g_u_i_1_1_base_view_layouter.html", [
          [ "AutoSizeViewLayouter", "struct_v_s_t_g_u_i_1_1_auto_size_view_layouter.html", null ],
          [ "NoViewLayouter", "struct_v_s_t_g_u_i_1_1_no_view_layouter.html", null ]
        ] ],
        [ "GridLayouter", "class_v_s_t_g_u_i_1_1_grid_layouter.html", null ]
      ] ],
      [ "ReferenceCounted< T >", "class_v_s_t_g_u_i_1_1_reference_counted.html", null ]
    ] ],
    [ "IScaleFactorChangedListener", "class_v_s_t_g_u_i_1_1_i_scale_factor_changed_listener.html", [
      [ "CExternalControl", "class_v_s_t_g_u_i_1_1_c_external_control.html", null ],
      [ "CExternalView", "class_v_s_t_g_u_i_1_1_c_external_view.html", null ],
      [ "CLayeredViewContainer", "class_v_s_t_g_u_i_1_1_c_layered_view_container.html", null ],
      [ "COpenGLView", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html", null ],
      [ "CShadowViewContainer", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html", null ]
    ] ],
    [ "IScrollbarDrawer", "class_v_s_t_g_u_i_1_1_i_scrollbar_drawer.html", null ],
    [ "ISplitViewController", "class_v_s_t_g_u_i_1_1_i_split_view_controller.html", null ],
    [ "ISplitViewSeparatorDrawer", "class_v_s_t_g_u_i_1_1_i_split_view_separator_drawer.html", null ],
    [ "IStyleProvider", "struct_v_s_t_g_u_i_1_1_text_editor_colorization_1_1_i_style_provider.html", null ],
    [ "Item", "struct_v_s_t_g_u_i_1_1_data_package_iterator_1_1_item.html", null ],
    [ "Iterator< reverse >", "class_v_s_t_g_u_i_1_1_c_view_container_1_1_iterator.html", null ],
    [ "ITextEditListener", "class_v_s_t_g_u_i_1_1_i_text_edit_listener.html", [
      [ "TextEditListenerAdapter", "class_v_s_t_g_u_i_1_1_text_edit_listener_adapter.html", null ]
    ] ],
    [ "ITextEditor", "struct_v_s_t_g_u_i_1_1_i_text_editor.html", [
      [ "TextEditorView", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_text_editor_view.html", null ]
    ] ],
    [ "ITextEditorController", "struct_v_s_t_g_u_i_1_1_i_text_editor_controller.html", [
      [ "TextEditorControllerAdapter", "struct_v_s_t_g_u_i_1_1_text_editor_controller_adapter.html", null ]
    ] ],
    [ "ITextLabelListener", "class_v_s_t_g_u_i_1_1_i_text_label_listener.html", [
      [ "TextLabelListenerAdapter", "class_v_s_t_g_u_i_1_1_text_label_listener_adapter.html", null ]
    ] ],
    [ "ITimingFunction", "class_v_s_t_g_u_i_1_1_animation_1_1_i_timing_function.html", [
      [ "RepeatTimingFunction", "class_v_s_t_g_u_i_1_1_animation_1_1_repeat_timing_function.html", null ],
      [ "TimingFunctionBase", "class_v_s_t_g_u_i_1_1_animation_1_1_timing_function_base.html", [
        [ "CubicBezierTimingFunction", "class_v_s_t_g_u_i_1_1_animation_1_1_cubic_bezier_timing_function.html", null ],
        [ "InterpolationTimingFunction", "class_v_s_t_g_u_i_1_1_animation_1_1_interpolation_timing_function.html", null ],
        [ "LinearTimingFunction", "class_v_s_t_g_u_i_1_1_animation_1_1_linear_timing_function.html", null ],
        [ "PowerTimingFunction", "class_v_s_t_g_u_i_1_1_animation_1_1_power_timing_function.html", null ]
      ] ]
    ] ],
    [ "IUIDescription", "class_v_s_t_g_u_i_1_1_i_u_i_description.html", [
      [ "UIDescription", "class_v_s_t_g_u_i_1_1_u_i_description.html", null ]
    ] ],
    [ "IUIDescriptionAddOn", "struct_v_s_t_g_u_i_1_1_i_u_i_description_add_on.html", [
      [ "UIDescriptionAddOnAdapter", "struct_v_s_t_g_u_i_1_1_u_i_description_add_on_adapter.html", null ]
    ] ],
    [ "IView", "struct_v_s_t_g_u_i_1_1_external_view_1_1_i_view.html", [
      [ "ViewAdapter", "struct_v_s_t_g_u_i_1_1_external_view_1_1_view_adapter.html", [
        [ "ControlViewAdapter", "struct_v_s_t_g_u_i_1_1_external_view_1_1_control_view_adapter.html", null ]
      ] ]
    ] ],
    [ "IViewAddedRemovedObserver", "class_v_s_t_g_u_i_1_1_i_view_added_removed_observer.html", [
      [ "VST3Editor", "class_v_s_t_g_u_i_1_1_v_s_t3_editor.html", null ]
    ] ],
    [ "IViewContainerListener", "class_v_s_t_g_u_i_1_1_i_view_container_listener.html", [
      [ "ViewContainerListenerAdapter", "class_v_s_t_g_u_i_1_1_view_container_listener_adapter.html", [
        [ "CLayeredViewContainer", "class_v_s_t_g_u_i_1_1_c_layered_view_container.html", null ],
        [ "CShadowViewContainer", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html", null ]
      ] ]
    ] ],
    [ "IViewCreator", "class_v_s_t_g_u_i_1_1_i_view_creator.html", [
      [ "ViewCreatorAdapter", "class_v_s_t_g_u_i_1_1_view_creator_adapter.html", [
        [ "AnimationSplashScreenCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_animation_splash_screen_creator.html", null ],
        [ "CheckBoxCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_check_box_creator.html", null ],
        [ "ControlCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_control_creator.html", null ],
        [ "GradientViewCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_gradient_view_creator.html", null ],
        [ "KnobBaseCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_knob_base_creator.html", [
          [ "AnimKnobCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_anim_knob_creator.html", null ],
          [ "KnobCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_knob_creator.html", null ]
        ] ],
        [ "LayeredViewContainerCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_layered_view_container_creator.html", null ],
        [ "MultiBitmapControlCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_multi_bitmap_control_creator.html", [
          [ "AutoAnimationCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_auto_animation_creator.html", null ],
          [ "KickButtonCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_kick_button_creator.html", null ],
          [ "MovieBitmapCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_movie_bitmap_creator.html", null ],
          [ "MovieButtonCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_movie_button_creator.html", null ],
          [ "RockerSwitchCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_rocker_switch_creator.html", null ]
        ] ],
        [ "MultiLineTextLabelCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_multi_line_text_label_creator.html", null ],
        [ "OnOffButtonCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_on_off_button_creator.html", null ],
        [ "OptionMenuCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_option_menu_creator.html", null ],
        [ "ParamDisplayCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_param_display_creator.html", null ],
        [ "RowColumnViewCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_row_column_view_creator.html", null ],
        [ "ScrollViewCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_scroll_view_creator.html", null ],
        [ "SearchTextEditCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_search_text_edit_creator.html", null ],
        [ "SegmentButtonCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_segment_button_creator.html", null ],
        [ "ShadowViewContainerCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_shadow_view_container_creator.html", null ],
        [ "SliderBaseCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_slider_base_creator.html", [
          [ "SliderCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_slider_creator.html", null ]
        ] ],
        [ "SplitViewCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_split_view_creator.html", null ],
        [ "StringListControlCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_string_list_control_creator.html", null ],
        [ "SwitchBaseCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_switch_base_creator.html", [
          [ "HorizontalSwitchCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_horizontal_switch_creator.html", null ],
          [ "VerticalSwitchCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_vertical_switch_creator.html", null ]
        ] ],
        [ "TextButtonCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_text_button_creator.html", null ],
        [ "TextEditCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_text_edit_creator.html", null ],
        [ "TextLabelCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_text_label_creator.html", null ],
        [ "UIViewSwitchContainerCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_u_i_view_switch_container_creator.html", null ],
        [ "ViewContainerCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_view_container_creator.html", null ],
        [ "ViewCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_view_creator.html", null ],
        [ "VuMeterCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_vu_meter_creator.html", null ],
        [ "XYPadCreator", "struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_x_y_pad_creator.html", null ]
      ] ]
    ] ],
    [ "IViewEmbedder", "struct_v_s_t_g_u_i_1_1_external_view_1_1_i_view_embedder.html", [
      [ "CExternalControl", "class_v_s_t_g_u_i_1_1_c_external_control.html", null ],
      [ "CExternalView", "class_v_s_t_g_u_i_1_1_c_external_view.html", null ]
    ] ],
    [ "IViewEventListener", "class_v_s_t_g_u_i_1_1_i_view_event_listener.html", [
      [ "ViewEventListenerAdapter", "class_v_s_t_g_u_i_1_1_view_event_listener_adapter.html", [
        [ "Impl", "struct_v_s_t_g_u_i_1_1_c_control_1_1_impl.html", null ],
        [ "FindPanelController", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_find_panel_controller.html", null ],
        [ "TextEditorView", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_text_editor_view.html", null ]
      ] ]
    ] ],
    [ "IViewFactory", "class_v_s_t_g_u_i_1_1_i_view_factory.html", [
      [ "UIViewFactory", "class_v_s_t_g_u_i_1_1_u_i_view_factory.html", null ],
      [ "ViewFactoryDelegate", "class_v_s_t_g_u_i_1_1_view_factory_delegate.html", null ]
    ] ],
    [ "IViewFactoryEditingSupport", "class_v_s_t_g_u_i_1_1_i_view_factory_editing_support.html", [
      [ "ViewFactoryDelegate", "class_v_s_t_g_u_i_1_1_view_factory_delegate.html", null ]
    ] ],
    [ "IViewListener", "class_v_s_t_g_u_i_1_1_i_view_listener.html", [
      [ "ViewListenerAdapter", "class_v_s_t_g_u_i_1_1_view_listener_adapter.html", [
        [ "CScrollView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html", null ],
        [ "FindPanelController", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_find_panel_controller.html", null ],
        [ "LineNumberView", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_line_number_view.html", null ]
      ] ]
    ] ],
    [ "IViewMouseListener", "class_v_s_t_g_u_i_1_1_i_view_mouse_listener.html", [
      [ "ViewMouseListenerAdapter", "class_v_s_t_g_u_i_1_1_view_mouse_listener_adapter.html", null ]
    ] ],
    [ "IViewSwitchController", "class_v_s_t_g_u_i_1_1_i_view_switch_controller.html", [
      [ "UIDescriptionViewSwitchController", "class_v_s_t_g_u_i_1_1_u_i_description_view_switch_controller.html", null ]
    ] ],
    [ "IVST3EditorDelegate", "class_v_s_t_g_u_i_1_1_i_v_s_t3_editor_delegate.html", [
      [ "VST3EditorDelegate", "class_v_s_t_g_u_i_1_1_v_s_t3_editor_delegate.html", null ]
    ] ],
    [ "Key", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_key.html", null ],
    [ "KeyboardHook", "struct_v_s_t3_editor_1_1_keyboard_hook.html", null ],
    [ "Line", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_line.html", null ],
    [ "ListenerProvider< T, ListenerInterface >", "struct_v_s_t_g_u_i_1_1_listener_provider.html", null ],
    [ "ListenerProvider< Impl, UIDescriptionListener >", "struct_v_s_t_g_u_i_1_1_listener_provider.html", [
      [ "Impl", "struct_v_s_t_g_u_i_1_1_u_i_description_1_1_impl.html", null ]
    ] ],
    [ "MallocAllocator", "struct_v_s_t_g_u_i_1_1_malloc_allocator.html", null ],
    [ "ModalViewSession", "struct_v_s_t_g_u_i_1_1_modal_view_session.html", null ],
    [ "ModelData", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_text_editor_view_1_1_model_data.html", null ],
    [ "Modifiers", "struct_v_s_t_g_u_i_1_1_modifiers.html", null ],
    [ "MouseEditingState", "struct_v_s_t_g_u_i_1_1_c_knob_base_1_1_mouse_editing_state.html", null ],
    [ "MouseEventButtonState", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html", null ],
    [ "MultiFrameBitmapView< T >", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html", null ],
    [ "MultiFrameBitmapView< CAnimKnob >", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html", [
      [ "CAnimKnob", "class_v_s_t_g_u_i_1_1_c_anim_knob.html", null ]
    ] ],
    [ "MultiFrameBitmapView< CAutoAnimation >", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html", [
      [ "CAutoAnimation", "class_v_s_t_g_u_i_1_1_c_auto_animation.html", null ]
    ] ],
    [ "MultiFrameBitmapView< CKickButton >", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html", [
      [ "CKickButton", "class_v_s_t_g_u_i_1_1_c_kick_button.html", null ]
    ] ],
    [ "MultiFrameBitmapView< CMovieBitmap >", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html", [
      [ "CMovieBitmap", "class_v_s_t_g_u_i_1_1_c_movie_bitmap.html", null ]
    ] ],
    [ "MultiFrameBitmapView< CMovieButton >", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html", [
      [ "CMovieButton", "class_v_s_t_g_u_i_1_1_c_movie_button.html", null ]
    ] ],
    [ "MultiFrameBitmapView< CRockerSwitch >", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html", [
      [ "CRockerSwitch", "class_v_s_t_g_u_i_1_1_c_rocker_switch.html", null ]
    ] ],
    [ "MultiFrameBitmapView< CSwitchBase >", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html", [
      [ "CSwitchBase", "class_v_s_t_g_u_i_1_1_c_switch_base.html", null ]
    ] ],
    [ "NewLineProcessor", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_new_line_processor.html", null ],
    [ "Optional< T >", "struct_v_s_t_g_u_i_1_1_optional.html", null ],
    [ "OutputStream", "class_v_s_t_g_u_i_1_1_output_stream.html", [
      [ "BufferedOutputStream", "class_v_s_t_g_u_i_1_1_buffered_output_stream.html", null ],
      [ "CFileStream", "class_v_s_t_g_u_i_1_1_c_file_stream.html", null ],
      [ "CMemoryStream", "class_v_s_t_g_u_i_1_1_c_memory_stream.html", null ],
      [ "StdOutStream", "class_v_s_t_g_u_i_1_1_std_out_stream.html", null ],
      [ "ZLibOutputStream", "class_v_s_t_g_u_i_1_1_z_lib_output_stream.html", null ]
    ] ],
    [ "Parser", "class_v_s_t_g_u_i_1_1_xml_1_1_parser.html", null ],
    [ "Percentage", "struct_v_s_t_g_u_i_1_1_grid_layout_properties_1_1_percentage.html", null ],
    [ "PlatformFileExtension", null, [
      [ "Impl", "struct_v_s_t_g_u_i_1_1_c_file_extension_1_1_impl.html", null ]
    ] ],
    [ "PlatformFileSelectorConfig", null, [
      [ "Impl", "struct_v_s_t_g_u_i_1_1_c_new_file_selector_1_1_impl.html", null ]
    ] ],
    [ "PostEventHandler", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl_1_1_post_event_handler.html", null ],
    [ "Preferences", "class_v_s_t_g_u_i_1_1_standalone_1_1_preferences.html", null ],
    [ "Property", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html", null ],
    [ "Range", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_range.html", null ],
    [ "Result", "struct_v_s_t_g_u_i_1_1_base64_codec_1_1_result.html", null ],
    [ "Row", "struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html", null ],
    [ "SeekableStream", "class_v_s_t_g_u_i_1_1_seekable_stream.html", [
      [ "CFileStream", "class_v_s_t_g_u_i_1_1_c_file_stream.html", null ],
      [ "CMemoryStream", "class_v_s_t_g_u_i_1_1_c_memory_stream.html", null ],
      [ "CResourceInputStream", "class_v_s_t_g_u_i_1_1_c_resource_input_stream.html", null ]
    ] ],
    [ "Segment", "struct_v_s_t_g_u_i_1_1_c_segment_button_1_1_segment.html", null ],
    [ "SharedPointer< I >", "class_v_s_t_g_u_i_1_1_shared_pointer.html", [
      [ "OwningPointer< I >", "class_v_s_t_g_u_i_1_1_owning_pointer.html", null ]
    ] ],
    [ "State", "struct_v_s_t_g_u_i_1_1_c_draw_context_1_1_impl_1_1_state.html", null ],
    [ "STB_TexteditState", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_s_t_b___textedit_state.html", null ],
    [ "StbFindState", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_find_state.html", null ],
    [ "StbTexteditRow", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_textedit_row.html", null ],
    [ "StbUndoRecord", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_undo_record.html", null ],
    [ "StbUndoState", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_undo_state.html", null ],
    [ "string", null, [
      [ "StringToken", "class_v_s_t_g_u_i_1_1_u_i_description_private_1_1_string_token.html", null ]
    ] ],
    [ "Style", "struct_v_s_t_g_u_i_1_1_i_text_editor_1_1_style.html", null ],
    [ "Style", "struct_v_s_t_g_u_i_1_1_text_editor_colorization_1_1_i_style_provider_1_1_style.html", null ],
    [ "TextModel", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_text_model.html", null ],
    [ "Transform", "struct_v_s_t_g_u_i_1_1_c_draw_context_1_1_transform.html", null ],
    [ "TrimOptions", "struct_v_s_t_g_u_i_1_1_trim_options.html", null ],
    [ "UIAttributesMap", null, [
      [ "UIAttributes", "class_v_s_t_g_u_i_1_1_u_i_attributes.html", null ]
    ] ],
    [ "UIDescriptionAddOnRegistry", "class_v_s_t_g_u_i_1_1_u_i_description_add_on_registry.html", null ],
    [ "UIDescriptionListener", "class_v_s_t_g_u_i_1_1_u_i_description_listener.html", [
      [ "UIDescriptionListenerAdapter", "class_v_s_t_g_u_i_1_1_u_i_description_listener_adapter.html", null ]
    ] ],
    [ "UIDescriptionListenerOff", "struct_v_s_t_g_u_i_1_1_u_i_description_listener_off.html", null ],
    [ "UndoGroup", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_text_editor_view_1_1_undo_group.html", null ],
    [ "UndoRecord", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_text_editor_view_1_1_undo_record.html", null ],
    [ "UTF8CharacterIterator", "class_v_s_t_g_u_i_1_1_u_t_f8_character_iterator.html", null ],
    [ "UTF8CodePointIterator< BaseIterator >", "class_v_s_t_g_u_i_1_1_u_t_f8_code_point_iterator.html", null ],
    [ "UTF8String", "class_v_s_t_g_u_i_1_1_u_t_f8_string.html", null ],
    [ "UTF8StringView", "class_v_s_t_g_u_i_1_1_u_t_f8_string_view.html", null ],
    [ "ValueCalls", "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html", null ],
    [ "ViewCreatorRegistryMap", null, [
      [ "ViewCreatorRegistry", "class_v_s_t_g_u_i_1_1_view_creator_registry.html", null ]
    ] ],
    [ "ViewLayout", "struct_v_s_t_g_u_i_1_1_view_layout.html", null ],
    [ "VSTGUIEditor", null, [
      [ "VST3Editor", "class_v_s_t_g_u_i_1_1_v_s_t3_editor.html", null ]
    ] ],
    [ "VSTGUIEditorInterface", "class_v_s_t_g_u_i_1_1_v_s_t_g_u_i_editor_interface.html", [
      [ "AEffGUIEditor", "class_v_s_t_g_u_i_1_1_a_eff_g_u_i_editor.html", null ],
      [ "PluginGUIEditor", "class_v_s_t_g_u_i_1_1_plugin_g_u_i_editor.html", null ]
    ] ],
    [ "VstKeyCode", "struct_vst_key_code.html", null ],
    [ "WindowConfiguration", "struct_v_s_t_g_u_i_1_1_standalone_1_1_window_configuration.html", null ],
    [ "WindowStyle", "struct_v_s_t_g_u_i_1_1_standalone_1_1_window_style.html", null ]
];